from ftw.globalstatusmessage import _
from ftw.globalstatusmessage.interfaces import IStatusMessageConfigForm
from plone.app.form.widgets.wysiwygwidget import WYSIWYGWidget
from plone.z3cform.layout import wrap_form
from z3c.form import form, field


class GlobalStatusMessageForm(form.EditForm):
    """This class defines the form"""
    schema = IStatusMessageConfigForm
    fields = field.Fields(IStatusMessageConfigForm)
    fields['message_textfield'].custom_widget = WYSIWYGWidget

    label = _(u"Global Statusmessage")


GlobalStatusMessageView = wrap_form(GlobalStatusMessageForm)



# -*- coding: utf-8 -*-
from ftw.globalstatusmessage.config import PROJECTNAME
from ftw.globalstatusmessage.interfaces import IStatusMessageConfigForm
from ftw.upgrade import UpgradeStep
from plone import api
from plone.registry.interfaces import IRegistry
from Products.CMFPlone.utils import safe_unicode
from zope.component import getUtility

import logging

LOG = logging.getLogger('ftw.globalstatusmessage.upgrades:1004')


class MigrateConfiglet(UpgradeStep):

    def __call__(self):
        # remove property sheet
        pprops = api.portal.get_tool('portal_properties')
        if 'ftw_globalstatusmessage_properties' in pprops:
            gsm_props = pprops.ftw_globalstatusmessage_properties
            del pprops['ftw_globalstatusmessage_properties']
        else:
            gsm_props = None

        # add registry records
        default = 'profile-{0}:default'.format(PROJECTNAME)
        setup = api.portal.get_tool('portal_setup')
        setup.runImportStepFromProfile(default, 'plone.app.registry')
        registry = getUtility(IRegistry)
        r = registry.forInterface(IStatusMessageConfigForm)

        # migrate current values
        if gsm_props is not None:
            r.enabled_bool = gsm_props.getProperty('Active', r.enabled_bool)
            r.type_choice = safe_unicode(
                gsm_props.getProperty('Type', r.type_choice))
            r.title_textfield = safe_unicode(
                gsm_props.getProperty('Title', r.title_textfield))
            r.message_textfield = safe_unicode(
                gsm_props.getProperty('Message', r.message_textfield))

        LOG.info('Configlet was migrated to plone.app.registry.')



# -*- coding: utf-8 -*-
from ftw.globalstatusmessage import _
from ftw.globalstatusmessage.interfaces import IStatusMessageConfigForm
from plone.app.registry.browser import controlpanel


class StatusMessageEditForm(controlpanel.RegistryEditForm):
    schema = IStatusMessageConfigForm
    label = _(u'Global Status Message')
    description = _(u'Settings for Global Status Message.')


class StatusMessageControlPanel(controlpanel.ControlPanelFormWrapper):
    form = StatusMessageEditForm



from ftw.globalstatusmessage import testing
from ftw.testbrowser import browsing
from ftw.testbrowser.pages import plone
from unittest2 import TestCase


class TestNotInstalled(TestCase):
    layer = testing.STATUSMESSAGE_ZCML_FUNCTIONAL

    @browsing
    def test_viewlet_should_not_break(self, browser):
        # When the package is not installed, the viewlet should
        # not break anything.

        browser.open()
        self.assertEquals('Plone site', plone.first_heading())
        self.assertNotIn(
            'error',
            browser.css('#portal-top').first.text,
            'The viewlet should not be rendered, but it seems'
            ' to have been rendered with an error.')



# -*- coding: utf-8 -*-
from ftw.globalstatusmessage import _
from plone.supermodel import model
from zope import schema
from zope.interface import Interface


class IStatusMessageConfigForm(model.Schema):
    """This interface defines the configlet."""

    enabled_bool = schema.Bool(
        title=_(u"statusmessage_label_Active", default=u"Active"),
        required=False)

    enabled_anonymous_bool = schema.Bool(
        title=_(u"statusmessage_label_anonymous", default=u"Show to anonymous users?"),
        default=True,  # for backward compatibility
        required=False)

    type_choice = schema.Choice(
        title=_(u"statusmessage_label_type", default=u"Type"),
        values=[_(u"information"),
                _(u"warning"),
                _(u"error")],
        required=False)

    title_textfield = schema.TextLine(
        title=_(u"statusmessage_label_title", default=u"Title"),
        required=False)

    message_textfield = schema.Text(
        title=_(u"statusmessage_label_message", default=u"Message"),
        required=False)

    exclude_sites = schema.List(
        title=_(u'statusmessage_label_exclude_sites',
                default=u'Exclude sites'),
        description=_(u'statusmessage_help_exclude_sites',
                      default=u'The message will not be shown on any content'
                      u' within containers which are selected here.'
                      u' If however a container is selected but a selectable'
                      u' sub container is not selected, contents within the'
                      u' the sub container will display the message.'),
        required=False,
        value_type=schema.Choice(
            vocabulary='ftw.globalstatusmessage:sites_vocabulary'))


class IGlobalStatusMessageLayer(Interface):
    """ftw.globalstatusmessage browser layer.
    """



# -*- coding: utf-8 -*-
from ftw.globalstatusmessage.config import PROJECTNAME
from ftw.globalstatusmessage.interfaces import IStatusMessageConfigForm
from ftw.globalstatusmessage.testing import STATUSMESSAGE_FUNCTIONAL
from plone import api
from plone.registry.interfaces import IRegistry
from zope.component import getUtility

import unittest2 as unittest


class UpgradeTestCaseBase(unittest.TestCase):

    layer = STATUSMESSAGE_FUNCTIONAL

    def setUp(self, from_version, to_version):
        self.portal = self.layer['portal']
        self.setup = self.portal['portal_setup']
        self.profile_id = u'ftw.globalstatusmessage:default'
        self.from_version = from_version
        self.to_version = to_version

    def _get_upgrade_step(self, title):
        self.setup.setLastVersionForProfile(self.profile_id, self.from_version)
        upgrades = self.setup.listUpgrades(self.profile_id)
        steps = []
        for s in upgrades:
            try:
                if s['title'] == title:  # handle single upgrade steps
                    steps.append(s)
            except TypeError:
                if s[0]['title'] == title:  # handle lists of upgrade steps
                    steps.append(s[0])

        assert len(steps) == 1
        return steps[0]

    def _do_upgrade_step(self, step):
        request = self.layer['request']
        request.form['profile_id'] = self.profile_id
        request.form['upgrades'] = [step['id']]
        self.setup.manage_doUpgrades(request=request)

    def _how_many_upgrades_to_do(self):
        self.setup.setLastVersionForProfile(self.profile_id, self.from_version)
        upgrades = self.setup.listUpgrades(self.profile_id)
        assert len(upgrades) > 0
        return len(upgrades)


class Upgrade1003to1004TestCase(UpgradeTestCaseBase):

    def setUp(self):
        UpgradeTestCaseBase.setUp(self, u'1003', u'1004')

    def test_upgrade_step_registrations(self):
        version = self.setup.getLastVersionForProfile(self.profile_id)[0]
        self.assertTrue(version >= self.to_version)
        self.assertGreaterEqual(self._how_many_upgrades_to_do(), 1)

    def test_upgrade_step(self):
        title = u'Migrate configlet to plone.app.registry'
        step = self._get_upgrade_step(title)
        self.assertIsNotNone(step)

        # simulate state on previous profile version
        pprops = self.portal['portal_properties']
        # add ftw_globalstatusmessage_properties property sheet
        pprops.addPropertySheet('ftw_globalstatusmessage_properties')
        self.assertIn('ftw_globalstatusmessage_properties', pprops)
        # remove registry records
        uninstall = 'profile-{0}:uninstall'.format(PROJECTNAME)
        setup = api.portal.get_tool('portal_setup')
        setup.runImportStepFromProfile(uninstall, 'plone.app.registry')
        registry = getUtility(IRegistry)
        with self.assertRaises(KeyError):
            registry.forInterface(IStatusMessageConfigForm)

        # run the upgrade step to validate the update
        self._do_upgrade_step(step)

        self.assertNotIn('ftw_globalstatusmessage_properties', pprops)
        fields = [
            'enabled_bool',
            'type_choice',
            'title_textfield',
            'message_textfield',
        ]
        settings = registry.forInterface(IStatusMessageConfigForm)
        for f in fields:
            self.assertTrue(hasattr(settings, f))


class Upgrade1400to1500TestCase(UpgradeTestCaseBase):

    def setUp(self):
        UpgradeTestCaseBase.setUp(self, u'1400', u'1500')

    def test_upgrade_step_registrations(self):
        version = self.setup.getLastVersionForProfile(self.profile_id)[0]
        self.assertGreaterEqual(version, self.to_version)
        self.assertGreaterEqual(self._how_many_upgrades_to_do(), 1)

    def test_upgrade_registry(self):
        title = u'Update registry: enable new configuration enabled_anonymous'
        step = self._get_upgrade_step(title)
        self.assertIsNotNone(step)

        from plone.registry.interfaces import IRegistry
        from zope.component import getUtility
        registry = getUtility(IRegistry)

        # simulate state on previous version
        record = IStatusMessageConfigForm.__identifier__ + '.enabled_anonymous_bool'
        del registry.records[record]

        with self.assertRaises(KeyError):
            registry.forInterface(IStatusMessageConfigForm)

        # execute upgrade step and verify changes were applied
        self._do_upgrade_step(step)
        settings = registry.forInterface(IStatusMessageConfigForm)
        self.assertTrue(hasattr(settings, 'enabled_anonymous_bool'))
        self.assertEqual(settings.enabled_anonymous_bool, True)





def is_path_included(path, included_paths, excluded_paths):
    """Helper function for testing whether a path is in within any
    container in included_paths or in excluded_paths.

    The nearest container path wins.
    If the path is not in any of included_paths or excluded_paths,
    ``True`` is returned as default.
    """
    sites = {'/': True}
    sites.update(dict((path, True) for path in included_paths))
    sites.update(dict((path, False) for path in excluded_paths))

    matching_sites = [site_path for site_path in sites.keys()
                      if path.startswith(site_path)]
    matching_sites.sort()
    return sites[matching_sites[-1]]



from Products.CMFCore.utils import getToolByName


def import_various(context):
    portal = context.getSite()
    action = context.readDataFile('ftw.globalstatusmessage.various.txt')
    action = action.strip() if action else None

    if action == 'uninstall':
        uninstall_controlpanel(portal)
        uninstall_property_sheet(portal)


def uninstall_controlpanel(portal):
    controlpanel = getToolByName(portal, 'portal_controlpanel')
    controlpanel.unregisterConfiglet('globalstatusmessage')


def uninstall_property_sheet(portal):
    properties = getToolByName(portal, 'portal_properties')
    if 'ftw_globalstatusmessage_properties' in properties.objectIds():
        properties.manage_delObjects(['ftw_globalstatusmessage_properties'])



# -*- coding: utf-8 -*-
from ftw.globalstatusmessage.config import PROJECTNAME
from ftw.globalstatusmessage.interfaces import IStatusMessageConfigForm
from ftw.globalstatusmessage.testing import STATUSMESSAGE_FUNCTIONAL
from plone.registry.interfaces import IRegistry
from zope.component import getUtility

import unittest2 as unittest


class RegistryTestCase(unittest.TestCase):

    layer = STATUSMESSAGE_FUNCTIONAL

    def setUp(self):
        self.portal = self.layer['portal']
        self.registry = getUtility(IRegistry)
        self.settings = self.registry.forInterface(IStatusMessageConfigForm)

    def test_enabled_bool_record_in_registry(self):
        self.assertTrue(hasattr(self.settings, 'enabled_bool'))
        self.assertFalse(self.settings.enabled_bool)

    def test_enabled_anonymous_bool_record_in_registry(self):
        self.assertTrue(hasattr(self.settings, 'enabled_anonymous_bool'))
        self.assertTrue(self.settings.enabled_anonymous_bool)

    def test_type_choice_record_in_registry(self):
        self.assertTrue(hasattr(self.settings, 'type_choice'))
        self.assertIsNone(self.settings.type_choice)

    def test_title_textfield_record_in_registry(self):
        self.assertTrue(hasattr(self.settings, 'title_textfield'))
        self.assertIsNone(self.settings.title_textfield)

    def test_message_textfield_record_in_registry(self):
        self.assertTrue(hasattr(self.settings, 'message_textfield'))
        self.assertIsNone(self.settings.message_textfield)

    def test_records_removed_on_uninstall(self):
        qi = self.portal['portal_quickinstaller']
        qi.uninstallProducts(products=[PROJECTNAME])

        BASE_REGISTRY = 'ftw.globalstatusmessage.interfaces.IStatusMessageConfigForm.'
        records = [
            BASE_REGISTRY + 'enabled_bool',
            BASE_REGISTRY + 'enabled_anonymous_bool',
            BASE_REGISTRY + 'type_choice',
            BASE_REGISTRY + 'title_textfield',
            BASE_REGISTRY + 'message_textfield',
        ]

        for r in records:
            self.assertNotIn(r, self.registry)



from Products.CMFCore.utils import getToolByName
from zope.component.hooks import getSite
from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary


def sites_vocabulary_factory(_records_proxy):
    portal = getSite()
    terms = [SimpleTerm('/'.join(portal.getPhysicalPath()),
                        title=portal.Title())]

    catalog = getToolByName(portal, 'portal_catalog')
    query = {
        'object_provides': [
            'plone.app.layout.navigation.interfaces.INavigationRoot'],
        'sort_on': 'sortable_title'}

    for brain in catalog(query):
        terms.append(SimpleTerm(brain.getPath(), title=brain.Title))

    return SimpleVocabulary(terms)



from ftw.globalstatusmessage.utils import is_path_included
from unittest2 import TestCase


class TestIsPathIncluded(TestCase):

    def test_included(self):
        self.assert_inclusion(
            {'/foo': True},
            included=['/'],
            excluded=[])

    def test_excluded(self):
        self.assert_inclusion(
            {'/foo': False},
            included=[],
            excluded=['/'])

    def test_exclude_top_include_below(self):
        self.assert_inclusion(
            {'/plone/subsite': True,
             '/plone/subsite/page': True,
             '/plone/page': False},
            included=['/plone/subsite'],
            excluded=['/plone'])

    def test_nested_subsites(self):
        self.assert_inclusion(
            {'/plone': True,
             '/plone/page': True,
             '/plone/siteA': False,
             '/plone/siteA/page': False,
             '/plone/siteA/siteB': True,
             '/plone/siteA/siteB/page': True},

            included=['/plone',
                      '/plone/siteA/siteB'],
            excluded=['/plone/siteA'])

    def assert_inclusion(self, expectation, included, excluded):
        got = dict((path, is_path_included(path, included, excluded))
                   for path in expectation.keys())
        self.assertEquals(expectation, got)



# -*- coding: utf-8 -*-
from ftw.globalstatusmessage.config import PROJECTNAME
from ftw.globalstatusmessage.testing import STATUSMESSAGE_FUNCTIONAL
from plone.app.testing import logout
from zope.component import getMultiAdapter

import unittest2 as unittest


class ControlPanelTestCase(unittest.TestCase):

    layer = STATUSMESSAGE_FUNCTIONAL

    def setUp(self):
        self.portal = self.layer['portal']
        self.request = self.layer['request']
        self.controlpanel = self.portal['portal_controlpanel']

    def test_controlpanel_has_view(self):
        view = getMultiAdapter(
            (self.portal, self.request), name='global_statusmessage_config')
        view = view.__of__(self.portal)
        self.assertTrue(view())

    def test_controlpanel_view_is_protected(self):
        from AccessControl import Unauthorized
        logout()
        with self.assertRaises(Unauthorized):
            self.portal.restrictedTraverse('@@global_statusmessage_config')

    def test_controlpanel_installed(self):
        actions = [a.getAction(self)['id']
                   for a in self.controlpanel.listActions()]
        self.assertIn('globalstatusmessage', actions)

    def test_controlpanel_removed_on_uninstall(self):
        qi = self.portal['portal_quickinstaller']
        qi.uninstallProducts(products=[PROJECTNAME])
        actions = [a.getAction(self)['id']
                   for a in self.controlpanel.listActions()]
        self.assertNotIn('globalstatusmessage', actions)



# -*- coding: utf-8 -*-
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from ftw.globalstatusmessage.interfaces import IStatusMessageConfigForm
from ftw.globalstatusmessage.utils import is_path_included
from plone import api
from plone.app.layout.viewlets import common
from plone.registry.interfaces import IRegistry
from zope.component import getUtility
from zope.schema.interfaces import IVocabularyFactory


class StatusmessageViewlet(common.PathBarViewlet):
    index = ViewPageTemplateFile('statusmessage.pt')

    def update(self):
        super(StatusmessageViewlet, self).update()

    def render(self):
        registry = getUtility(IRegistry)
        self.settings = registry.forInterface(IStatusMessageConfigForm)

        if not self.settings.enabled_bool:
            return ''

        if api.user.is_anonymous() and not self.settings.enabled_anonymous_bool:
            return ''

        if not self.show_in_current_context():
            return ''

        return self.index()

    def show_in_current_context(self):
        excluded_site_paths = self.settings.exclude_sites or []
        if not excluded_site_paths:
            return True

        included_site_paths = set(self._all_sites_paths()) \
                              - set(excluded_site_paths)
        return is_path_included('/'.join(self.context.getPhysicalPath()),
                                included_site_paths,
                                excluded_site_paths)

    def _all_sites_paths(self):
        vocabulary_factory = getUtility(
            IVocabularyFactory,
            name='ftw.globalstatusmessage:sites_vocabulary')
        return [term.value for term in vocabulary_factory(None)]



from ftw.builder import Builder
from ftw.builder import create
from ftw.globalstatusmessage.testing import STATUSMESSAGE_FUNCTIONAL
from ftw.testbrowser import browser
from ftw.testbrowser import browsing
from plone.app.layout.navigation.interfaces import INavigationRoot
from plone.app.testing import setRoles
from plone.app.testing import SITE_OWNER_NAME
from plone.app.testing import TEST_USER_ID
from unittest2 import TestCase


def statusmessage():
    if not browser.css('#globalstatusmessage dl'):
        return None
    dl = browser.css('#globalstatusmessage dl').first
    return {'type': dl.classes[1],
            'title': dl.terms[0],
            'message': dl.definitions[0]}


class TestConfiguringStatusMessage(TestCase):
    layer = STATUSMESSAGE_FUNCTIONAL

    def setUp(self):
        self.portal = self.layer['portal']
        setRoles(self.portal, TEST_USER_ID, ['Manager'])

    @browsing
    def test_no_viewlet_by_default(self, browser):
        browser.open()
        self.assertEquals(None, statusmessage(),
                          'Expected no default status message.')

    @browsing
    def test_info_status_message(self, browser):
        browser.login(SITE_OWNER_NAME).visit(
            view='global_statusmessage_config')
        browser.fill(
            {'Active': True,
             'Type': 'information',
             'Title': 'Maintenance',
             'Message': 'Scheduled maintenance 20PM-22PM'}).submit()

        self.assertEquals(
            {'type': 'information',
             'title': 'Maintenance',
             'message': 'Scheduled maintenance 20PM-22PM'},
            statusmessage())

    @browsing
    def test_error_status_message(self, browser):
        browser.login(SITE_OWNER_NAME).visit(
            view='global_statusmessage_config')
        browser.fill(
            {'Active': True,
             'Type': 'error',
             'Title': 'Outage',
             'Message': 'Some parts are not available'}).submit()

        self.assertEquals(
            {'type': 'error',
             'title': 'Outage',
             'message': 'Some parts are not available'},
            statusmessage())

    @browsing
    def test_disabling_status_message(self, browser):
        browser.login(SITE_OWNER_NAME).visit(
            view='global_statusmessage_config')
        browser.fill(
            {'Active': True,
             'Type': 'information',
             'Title': 'Maintenance',
             'Message': 'Scheduled maintenance 20PM-22PM'}).submit()
        self.assertTrue(statusmessage(),
                        'Expected a message to be configured.')

        browser.visit(view='global_statusmessage_config')
        browser.fill({'Active': False}).submit()
        self.assertFalse(statusmessage(),
                        'Expected message to be no longer visible.')

    @browsing
    def test_exclude_subsite(self, browser):
        subsite = create(Builder('folder')
                         .titled('The Subsite')
                         .providing(INavigationRoot))

        browser.login().visit(view='global_statusmessage_config')
        browser.fill(
            {'Active': True,
             'Type': 'information',
             'Title': 'Maintenance',
             'Message': 'Scheduled Maintenance',
             'Exclude sites': ['The Subsite']}).submit()


        browser.visit(self.portal)
        self.assertTrue(
            statusmessage(),
            'Status message should be visible on site root.')

        page_on_site_root = create(Builder('page'))
        browser.visit(page_on_site_root)
        self.assertTrue(
            statusmessage(),
            'Status message should be visible on pages within site root.')

        browser.visit(subsite)
        self.assertFalse(
            statusmessage(),
            'Status message should not be visible on subsite.')

        page_on_subsite = create(Builder('page').within(subsite))
        browser.visit(page_on_subsite)
        self.assertFalse(
            statusmessage(),
            'Status message should not be visible on pages within subsite.')

    @browsing
    def test_exclude_site_root(self, browser):
        subsite = create(Builder('folder')
                         .titled('The Subsite')
                         .providing(INavigationRoot))

        browser.login().visit(view='global_statusmessage_config')
        browser.fill(
            {'Active': True,
             'Type': 'information',
             'Title': 'Maintenance',
             'Message': 'Scheduled Maintenance',
             'Exclude sites': ['Plone site']}).submit()


        browser.visit(self.portal)
        self.assertFalse(
            statusmessage(),
            'Status message should not be visible on site root.')

        page_on_site_root = create(Builder('page'))
        browser.visit(page_on_site_root)
        self.assertFalse(
            statusmessage(),
            'Status message should not be visible on pages within site root.')

        browser.visit(subsite)
        self.assertTrue(
            statusmessage(),
            'Status message should be visible on subsite.')

        page_on_subsite = create(Builder('page').within(subsite))
        browser.visit(page_on_subsite)
        self.assertTrue(
            statusmessage(),
            'Status message should be visible on pages within subsite.')

    @browsing
    def test_disable_for_anonymous(self, browser):
        subsite = create(Builder('folder')
                         .titled('The Subsite')
                         .providing(INavigationRoot))

        browser.login().visit(view='global_statusmessage_config')
        browser.fill(
            {'Active': True,
             'Type': 'information',
             'Title': 'Maintenance',
             'Message': 'Scheduled Maintenance'}).submit()

        browser.logout().visit(self.portal)
        self.assertTrue(
            statusmessage(),
            'Status should be visible for anonymous by default.')

        browser.login().visit(view='global_statusmessage_config')
        browser.fill(
            {'Show to anonymous users?': False}).submit()

        browser.visit(self.portal)
        self.assertTrue(
            statusmessage(),
            'Status should still visible for logged in users.')

        browser.logout().reload()
        self.assertFalse(
            statusmessage(),
            'Status should no longer be visible for anonymous in users.')



from ftw.globalstatusmessage.interfaces import IStatusMessageConfigForm
from ftw.upgrade import UpgradeStep
from zope.component import getSiteManager
from zope.component import queryUtility
import logging


LOG = logging.getLogger('ftw.globalstatusmessage.upgrades:1003')


class RemoveUtility(UpgradeStep):

    def __call__(self):
        utility = queryUtility(IStatusMessageConfigForm,
                               name='Global_Statusmessage')

        if utility:
            LOG.info('Removing IStatusMessageConfigForm utility.')
            sitemanager = getSiteManager()
            sitemanager.unregisterUtility(
                component=utility,
                provided=IStatusMessageConfigForm,
                name='Global_Statusmessage')

        else:
            LOG.info('IStatusMessageConfigForm utility already removed.')



from ftw.builder.testing import BUILDER_LAYER
from ftw.builder.testing import functional_session_factory
from ftw.builder.testing import set_builder_session_factory
from plone.app.testing import FunctionalTesting
from plone.app.testing import PLONE_FIXTURE
from plone.app.testing import PloneSandboxLayer
from plone.app.testing import applyProfile
from zope.configuration import xmlconfig
import logging
import sys


handler = logging.StreamHandler(sys.stderr)
logging.root.addHandler(handler)


class ZCMLLayer(PloneSandboxLayer):

    defaultBases = (PLONE_FIXTURE, )

    def setUpZope(self, app, configurationContext):
        import ftw.globalstatusmessage
        xmlconfig.file('configure.zcml',
                       ftw.globalstatusmessage,
                       context=configurationContext)

STATUSMESSAGE_ZCML_LAYER = ZCMLLayer()
STATUSMESSAGE_ZCML_FUNCTIONAL = FunctionalTesting(
    bases=(STATUSMESSAGE_ZCML_LAYER, ),
    name="ftw.globalstatusmessage:zcml:functional")


class InstallationLayer(PloneSandboxLayer):

    defaultBases = (STATUSMESSAGE_ZCML_LAYER, BUILDER_LAYER)

    def setUpPloneSite(self, portal):
        applyProfile(portal, 'ftw.globalstatusmessage:default')


STATUSMESSAGE_FIXTURE = InstallationLayer()
STATUSMESSAGE_FUNCTIONAL = FunctionalTesting(
    bases=(STATUSMESSAGE_FIXTURE,
           set_builder_session_factory(functional_session_factory)),
    name="ftw.globalstatusmessage:functional")



from setuptools import setup, find_packages
import os


tests_require = [
    'AccessControl',
    'ftw.builder',
    'ftw.testbrowser',
    'ftw.testing',
    'plone.app.testing',
    'unittest2',
    'zope.configuration',
    ]


def read(*rnames):
    return open('/'.join(rnames)).read()

version = '1.5.0'
maintainer = 'Mathias Leimgruber'


setup(name='ftw.globalstatusmessage',
      version=version,
      description="Shows a global message on every site.",
      long_description=open("README.rst").read() + "\n" + \
          open(os.path.join("docs", "HISTORY.txt")).read(),

      # Get more strings from
      # http://www.python.org/pypi?%3Aaction=list_classifiers

      classifiers=[
        'Framework :: Plone',
        'Framework :: Plone :: 4.2',
        'Framework :: Plone :: 4.3',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
        ],

      keywords='ftw global status message plone',
      author='4teamwork AG',
      author_email='mailto:info@4teamwork.ch',
      url='https://github.com/4teamwork/ftw.globalstatusmessage',
      license='GPL2',

      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['ftw'],
      include_package_data=True,
      zip_safe=False,

      install_requires=[
        'Plone',
        'Products.CMFCore',
        'Products.CMFPlone',
        'Products.GenericSetup',
        'Zope2',
        'ftw.upgrade',
        'plone.api',
        'plone.app.form',
        'plone.app.layout',
        'plone.app.registry',
        'plone.registry',
        'plone.supermodel',
        'plone.z3cform',
        'setuptools',
        'z3c.form',
        'zope.component',
        'zope.i18nmessageid',
        'zope.interface',
        'zope.schema',
        ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),

      entry_points="""
      # -*- Entry points: -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )
